@@ -1,5 +1,7 @@
+import requests
+
 def getResource():
-    url = "http://3.39.12.67:8083/jobs"
+    url = "http://3.39.12.67:8083/qcc/jobs"
 
     response = requests.get(f"{url}", headers=headers) # , params=params)
 
